<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>KvantumPreviewBase</name>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="14"/>
        <source>Kvantum Preview</source>
        <translation>Pré-visualização Kvantum</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="29"/>
        <source>Push buttons</source>
        <translation>Botões de apertar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="77"/>
        <source>Toggle
push
button

with
height
greater
than
width</source>
        <translation>Alternar
apertar
botão

com
altura
maior
que
largura</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="95"/>
        <location filename="../../KvantumPreviewBase.ui" line="105"/>
        <source>Simple push button</source>
        <translation>Botão de apertar simples</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="112"/>
        <location filename="../../KvantumPreviewBase.ui" line="128"/>
        <source>Toggle push button</source>
        <translation>Botão de alternar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="141"/>
        <location filename="../../KvantumPreviewBase.ui" line="152"/>
        <source>Multi-line
 push button</source>
        <translation>Multi-linha
 botão de apertar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="160"/>
        <location filename="../../KvantumPreviewBase.ui" line="180"/>
        <source>Push button
with 32px folder icon</source>
        <translation>Botão de apertar
com ícone de pasta de 32px</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="210"/>
        <location filename="../../KvantumPreviewBase.ui" line="224"/>
        <source>Default
push button</source>
        <translation>Padrão
botão de apertar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="266"/>
        <source>Flat buttons</source>
        <translation>Botões planos</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="279"/>
        <source>Button Box</source>
        <translation>Botão caixa</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="374"/>
        <source>Tool buttons</source>
        <translation>Botões de ferramentas</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="382"/>
        <location filename="../../KvantumPreviewBase.ui" line="459"/>
        <source>Simple toolbutton</source>
        <translation>Botão de ferramenta simples</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="466"/>
        <location filename="../../KvantumPreviewBase.ui" line="477"/>
        <source>Multi-line
toolbutton</source>
        <translation>Multilinha
botão de ferramenta</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="485"/>
        <location filename="../../KvantumPreviewBase.ui" line="508"/>
        <source>Toggle toolbutton
with an arrow</source>
        <translation>Botão de ferramenta de alternar
com uma seta</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="573"/>
        <location filename="../../KvantumPreviewBase.ui" line="597"/>
        <source>Toolbutton with 32px SVG icon
and text below</source>
        <translation>Botão de ferramenta com o ícone SVG de 32px
e texto abaixo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="618"/>
        <location filename="../../KvantumPreviewBase.ui" line="639"/>
        <source>Toolbutton with text below
and arrow</source>
        <translation>Botão de ferramenta com o texto abaixo
e seta</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="657"/>
        <location filename="../../KvantumPreviewBase.ui" line="678"/>
        <source>Toolbutton with icon at the side
and arrow</source>
        <translation>Botão de ferramenta com o ícone ao lado
e seta</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="696"/>
        <location filename="../../KvantumPreviewBase.ui" line="723"/>
        <source>Toggle toolbutton with icon,
ordinary arrow
and dropdown menu arrow</source>
        <translation>Botão de ferramenta de alternar com ícone
seta comum
e seta de menu suspenso</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="528"/>
        <location filename="../../KvantumPreviewBase.ui" line="552"/>
        <source>Toolbutton with 32px PNG icon
beside text</source>
        <translation>Botão de ferramenta com o ícone PNG de 32px
ao lado do texto</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="366"/>
        <source>Push button with menu</source>
        <translation>Premir botão com menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="415"/>
        <source>Toggle
tool
button

with
height
greater
than
width</source>
        <translation>Alternar
ferramenta
botão

com
altura
maior
que
largura</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="804"/>
        <source>Auto-raise</source>
        <translation>Aumento automático</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="825"/>
        <source>Radio/Check buttons</source>
        <translation>Botões de Opção/Seleção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="846"/>
        <location filename="../../KvantumPreviewBase.ui" line="859"/>
        <source>Simple radio button</source>
        <translation>Botão de opção simples</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="869"/>
        <location filename="../../KvantumPreviewBase.ui" line="880"/>
        <source>Multi-line
radio button</source>
        <translation>Multi-linha
botão de opção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="891"/>
        <location filename="../../KvantumPreviewBase.ui" line="917"/>
        <source>Radio button with 32px SVG icon</source>
        <translation>Botão de opção com ícone SVG de 32px</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="940"/>
        <location filename="../../KvantumPreviewBase.ui" line="953"/>
        <source>Simple check box</source>
        <translation>Caixa de seleção simples</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="963"/>
        <location filename="../../KvantumPreviewBase.ui" line="974"/>
        <source>Multi-line
check box</source>
        <translation>Multi-linha
caixa de seleção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="982"/>
        <location filename="../../KvantumPreviewBase.ui" line="995"/>
        <source>Tri-state check box</source>
        <translation>Caixa de seleção tri-estado</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1005"/>
        <location filename="../../KvantumPreviewBase.ui" line="1019"/>
        <source>Check box with icon</source>
        <translation>Caixa de seleção com ícone</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1075"/>
        <source>Combos/Spins/Inputs</source>
        <translation>Combinações/Rotações/Entradas</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1109"/>
        <location filename="../../KvantumPreviewBase.ui" line="1195"/>
        <location filename="../../KvantumPreviewBase.ui" line="1264"/>
        <location filename="../../KvantumPreviewBase.ui" line="1378"/>
        <location filename="../../KvantumPreviewBase.ui" line="1450"/>
        <location filename="../../KvantumPreviewBase.ui" line="1508"/>
        <source>Frameless (no difference)</source>
        <translation>Sem moldura (sem diferença)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1120"/>
        <location filename="../../KvantumPreviewBase.ui" line="1159"/>
        <source>Standard combo box</source>
        <translation>Caixa de combinação padrão</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1129"/>
        <location filename="../../KvantumPreviewBase.ui" line="1168"/>
        <source>Standard combo box 1</source>
        <translation>Caixa de combinação padrão 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1137"/>
        <location filename="../../KvantumPreviewBase.ui" line="1173"/>
        <source>Standard combo box 2</source>
        <translation>Caixa de combinação padrão 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1142"/>
        <location filename="../../KvantumPreviewBase.ui" line="1178"/>
        <source>Standard combo box 3</source>
        <translation>Caixa de combinação padrão 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1147"/>
        <location filename="../../KvantumPreviewBase.ui" line="1183"/>
        <source>Standard combo box 4</source>
        <translation>Caixa de combinação padrão 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1204"/>
        <location filename="../../KvantumPreviewBase.ui" line="1273"/>
        <location filename="../../KvantumPreviewBase.ui" line="1387"/>
        <location filename="../../KvantumPreviewBase.ui" line="1459"/>
        <source>Frameless 1</source>
        <translation>Sem moldura 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1209"/>
        <location filename="../../KvantumPreviewBase.ui" line="1278"/>
        <location filename="../../KvantumPreviewBase.ui" line="1392"/>
        <location filename="../../KvantumPreviewBase.ui" line="1464"/>
        <source>Frameless 2</source>
        <translation>Sem moldura 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1214"/>
        <location filename="../../KvantumPreviewBase.ui" line="1283"/>
        <location filename="../../KvantumPreviewBase.ui" line="1397"/>
        <location filename="../../KvantumPreviewBase.ui" line="1469"/>
        <source>Frameless 3</source>
        <translation>Sem moldura 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1219"/>
        <location filename="../../KvantumPreviewBase.ui" line="1288"/>
        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
        <location filename="../../KvantumPreviewBase.ui" line="1474"/>
        <source>Frameless 4</source>
        <translation>Sem moldura 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1224"/>
        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
        <source>Frameless 5</source>
        <translation>Sem moldura 5</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1229"/>
        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
        <source>Frameless 6</source>
        <translation>Sem moldura 6</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1234"/>
        <location filename="../../KvantumPreviewBase.ui" line="1417"/>
        <source>Frameless 7</source>
        <translation>Sem moldura 7</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1239"/>
        <location filename="../../KvantumPreviewBase.ui" line="1422"/>
        <source>Frameless 8</source>
        <translation>Sem moldura 8</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1244"/>
        <location filename="../../KvantumPreviewBase.ui" line="1427"/>
        <source>Frameless 9</source>
        <translation>Sem moldura 9</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1249"/>
        <location filename="../../KvantumPreviewBase.ui" line="1432"/>
        <source>Frameless 10</source>
        <translation>Sem moldura 10</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1300"/>
        <location filename="../../KvantumPreviewBase.ui" line="1339"/>
        <source>Editable combo box</source>
        <translation>Caixa de combinação editável</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1309"/>
        <location filename="../../KvantumPreviewBase.ui" line="1348"/>
        <source>Editable combo box 1</source>
        <translation>Caixa de combinação editável 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1314"/>
        <location filename="../../KvantumPreviewBase.ui" line="1353"/>
        <source>Editable combo box 2</source>
        <translation>Caixa de combinação editável 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1319"/>
        <location filename="../../KvantumPreviewBase.ui" line="1358"/>
        <source>Editable combo box 3</source>
        <translation>Caixa de combinação editável 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1324"/>
        <location filename="../../KvantumPreviewBase.ui" line="1363"/>
        <source>Editable combo box 4</source>
        <translation>Caixa de combinação editável 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1482"/>
        <location filename="../../KvantumPreviewBase.ui" line="1495"/>
        <source>Line-edit</source>
        <translation>Edição de linha</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1574"/>
        <source>Sliders/Scrolls/Progress/Dial</source>
        <translation>Deslizantes/Rodar/Progresso/Marcação</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2131"/>
        <source>Containers</source>
        <translation>Contentores</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2152"/>
        <source>Header 1</source>
        <translation>Cabeçalho 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2161"/>
        <source>Header 2</source>
        <translation>Cabeçalho 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2169"/>
        <source>Header 3</source>
        <translation>Cabeçalho 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2174"/>
        <location filename="../../KvantumPreviewBase.ui" line="2272"/>
        <source>3rd Item</source>
        <translation>3º Item</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2182"/>
        <location filename="../../KvantumPreviewBase.ui" line="2260"/>
        <source>2nd Item</source>
        <translation>2º Item</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2186"/>
        <location filename="../../KvantumPreviewBase.ui" line="2222"/>
        <source>2nd Child</source>
        <translation>2º Dependente</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2191"/>
        <location filename="../../KvantumPreviewBase.ui" line="2227"/>
        <source>1st Child</source>
        <translation>1º Dependente</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2197"/>
        <location filename="../../KvantumPreviewBase.ui" line="2245"/>
        <source>1st Item</source>
        <translation>1º Item</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2217"/>
        <source>3rd Child</source>
        <translation>3º Dependente</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2515"/>
        <source>Row 0</source>
        <translation>Linha 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
        <source>Row 1</source>
        <translation>Linha 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
        <source>Column 0</source>
        <translation>Coluna 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
        <source>Column 1</source>
        <translation>Coluna 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2538"/>
        <source>0-0</source>
        <translation>0-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2546"/>
        <source>0-1</source>
        <translation>0-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2554"/>
        <source>1-0</source>
        <translation>1-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2562"/>
        <source>1-1</source>
        <translation>1-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2204"/>
        <location filename="../../KvantumPreviewBase.ui" line="2207"/>
        <source>Editable</source>
        <translation>Editável</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2234"/>
        <source>Non-Editable</source>
        <translation>Não-Editável</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2282"/>
        <source>Subwindow</source>
        <translation>Janela inferior</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2329"/>
        <source>Panel frame</source>
        <translation>Moldura do painel</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2348"/>
        <location filename="../../KvantumPreviewBase.ui" line="2489"/>
        <location filename="../../KvantumPreviewBase.ui" line="2581"/>
        <source>GroupBox</source>
        <translation>Caixa de grupo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2368"/>
        <location filename="../../KvantumPreviewBase.ui" line="2420"/>
        <location filename="../../KvantumPreviewBase.ui" line="2714"/>
        <location filename="../../KvantumPreviewBase.ui" line="2791"/>
        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
        <source>Tab 1</source>
        <translation>Separador 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2374"/>
        <source>Page 1 (disabled)</source>
        <translation>Página 1 (desativado)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2386"/>
        <location filename="../../KvantumPreviewBase.ui" line="2434"/>
        <location filename="../../KvantumPreviewBase.ui" line="2732"/>
        <location filename="../../KvantumPreviewBase.ui" line="2805"/>
        <location filename="../../KvantumPreviewBase.ui" line="2853"/>
        <source>Tab 2</source>
        <translation>Separador 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2392"/>
        <source>Page 2 (disabled)</source>
        <translation>Página 2 (desativado)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2426"/>
        <location filename="../../KvantumPreviewBase.ui" line="2619"/>
        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
        <location filename="../../KvantumPreviewBase.ui" line="2797"/>
        <location filename="../../KvantumPreviewBase.ui" line="2845"/>
        <source>Page 1</source>
        <translation>Página 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2440"/>
        <location filename="../../KvantumPreviewBase.ui" line="2647"/>
        <location filename="../../KvantumPreviewBase.ui" line="2687"/>
        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
        <location filename="../../KvantumPreviewBase.ui" line="2811"/>
        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
        <source>Page 2</source>
        <translation>Página 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2464"/>
        <source>Stack widget (page1)</source>
        <translation>Widget de pilha (Página1)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2478"/>
        <source>Stack Widget (page2)</source>
        <translation>Widget de pilha (página2)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2495"/>
        <source>Group box</source>
        <translation>Caixa de grupo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2573"/>
        <source>Dock Widget</source>
        <translation>Widget de Doca</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2590"/>
        <source>Checkable group box</source>
        <translation>Caixa de grupo selecionável</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2625"/>
        <source>Tool Box</source>
        <translation>Caixa de ferramentas</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2720"/>
        <source>Document mode</source>
        <translation>Modo de documento</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
        <source>Box frame</source>
        <translation>Moldura da caixa</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2888"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2892"/>
        <source>&amp;Submenu</source>
        <translation>&amp;Sub-menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2912"/>
        <source>toolBar</source>
        <translation>barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2932"/>
        <source>toolBar_2</source>
        <translation>barra de ferramentas_2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2957"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2960"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
        <source>&amp;Checkbox</source>
        <translation>&amp;Caixa de seleção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2981"/>
        <source>Toggle Layout</source>
        <translation>Alternar a disposição</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2984"/>
        <source>Toggle layout direction</source>
        <translation>Alternar direção da disposição</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2996"/>
        <source>&amp;Doc Mode</source>
        <translation>Modo &amp;Doca</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2999"/>
        <source>Show tabs in the document mode</source>
        <translation>Mostrar separadores no modo de documento</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3011"/>
        <source>Menu Button</source>
        <translation>Botão de menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3014"/>
        <source>Hold pressed to show a menu</source>
        <translation>Mantenha pressionado para mostrar um menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3025"/>
        <source>C&amp;heckbox</source>
        <translation>C&amp;aixa de seleção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3033"/>
        <source>&amp;Radio button</source>
        <translation>Botão de &amp;opção</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3041"/>
        <source>Radio &amp;button</source>
        <translation>&amp;Botão de opção</translation>
    </message>
</context>
</TS>
